//+-----------------------------------------------------------------------------+
//|                                                    Daily Scalping v1.0b.mq4 |
//|                                                                Skyline 2007 |
//|                                                                             |
//+-----------------------------------------------------------------------------+
#property copyright "Skyline 2007"
#property link      ""
#include <stdlib.mqh>

// v1.0  (07 Feb 2007) : Start Project 
// v1.0a (07 Feb 2007) : Add GMT_Shift variable
// v1.0b (16 Feb 2007) : Added MagicNumber routine based on pair and timeframe

//---- Definizione parametri esterni 
extern double    GMT_Shift           = 0;
extern int       TakeProfit          = 0;
extern int       StopLoss            = 40;  
extern int       HourToCloseOrders   = 23;
extern bool      SundayCandleExists  = true;
extern double    Lots                = 0.1; 
extern bool      UseMoneyManagement  = false;
extern int       Risk                = 2;
extern int       Slippage            = 3;
 
//----- Definizione parametri interni 
static int TradeStatus = 0; //0 = Trades disabilitati , 1 = Solo Buy permessi, 2 = Solo Sell permessi 
int MagicNumber;

//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
   string TradeMode;
   
   // Calcola dimensione Lot in base all'Equity
   if (UseMoneyManagement==true) Lots = CalcolaLot(Risk);   
   
   // Calcola MagicNumber a seconda della coppia e timeframe 
   MagicNumber = MagicFromSymbol();

   // Attiva ordine alle 00:00 GMT 
   OpenOrderMidnight(Lots);
 
   // Attiva ordini successivi
   OpenNextOrders(Lots);
   
   // Chiude ordini allo scadere di HourToCloseOrders
   CloseAllOrders(HourToCloseOrders);
   
   // Commenti
   if (TradeStatus == 0) TradeMode = "NONE";
   if (TradeStatus == 1) TradeMode = "BUY";
   if (TradeStatus == 2) TradeMode = "SELL";
   
   Comment("\nDaily Scalping EA v1.0b (Skyline 2007)",
           "\nCompiled version on 16 Feb 2007",
           "\n\n---------------------------------------",
           "\nMagicNumber : ",MagicNumber,
           "\nNext Trade : ",TradeMode,
           "\nTimeFrame to be used : H1",
           "\n---------------------------------------");
           
   return(0);
  }
  
// ===== Routine per chiudere tutti gli ordini =====
void CloseAllOrders(int Ora)
{
 int total,cnt;
 
 total = OrdersTotal();
 if ( Hour()==MathMod(Ora+GMT_Shift,24) )
 {
  TradeStatus = 0; // azzera variabile globale per non aprire pi trade
  
  for(cnt=0;cnt<total;cnt++)
  {
   OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);
   if (OrderMagicNumber()==MagicNumber)
   {
    if (OrderType() == OP_BUY)  OrderClose(OrderTicket(),OrderLots(), Bid, Slippage, LimeGreen);
    if (OrderType() == OP_SELL) OrderClose(OrderTicket(),OrderLots(), Ask, Slippage, Red);
   }  // if (OrderMagicNumber()==MagicNumber)
  }  // for 
 } // if
}

// ===== Routine per aprire il primo ordine alle 00:00 GMT =====
void OpenOrderMidnight(double Lot)
{  int Ticket,Errore; 
   double SL,TP;
   int ActualSpread;
   
   RefreshRates();
   
   //ActualSpread = MarketInfo(Symbol(),MODE_SPREAD);
    
   int Total = OrdersTotal();
   
   if ( Total < 1 && Hour()==MathMod(24+GMT_Shift,24) && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {
     TradeStatus = 0; // azzera variabile globale 
      
   // Controlla BUY Order
   if (
      (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BULLISH") ||
      (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BEARISH") ||
      (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BEARISH") ||     
      (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BEARISH")
      )
    {   
      
      // Controlla SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Ask-StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Ask+TakeProfit*Point;
      // Piazza l'ordine BUY
      Ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,Slippage,SL,TP,"BUY ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 2; // Prossimo trade  Sell
      
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON BUY ORDER (",Errore,") : ",ErrorDescription(Errore));
      }  
     } 
   }
   
   Total = OrdersTotal();
   
   if ( Total < 1 && Hour()==MathMod(24+GMT_Shift,24) && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {
   
     // Controlla SELL Order
     if (
         (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BEARISH") ||
         (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BEARISH" && CheckTrend(3)=="BULLISH") ||
         (CheckTrend(1)=="BEARISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BULLISH") ||
         (CheckTrend(1)=="BULLISH" && CheckTrend(2)=="BULLISH" && CheckTrend(3)=="BULLISH")
        )
     {
 
      // Setta SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Bid+StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Bid-TakeProfit*Point;
      
      // Piazza Ordine SELL       
      Ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,SL,TP,"SELL ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 1; // Prossimo trade  Buy
      
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON SELL ORDER (",Errore,") : ",ErrorDescription(Errore));
      } 
      
     }    
   }
}

// ===== Routine per aprire ordini durante la giornata al raggiungimento dello SL o TP =====
void OpenNextOrders(double Lot)
{  int Ticket,Errore; 
   double SL,TP;
   int ActualSpread;
   
   RefreshRates();
   
   //ActualSpread = MarketInfo(Symbol(),MODE_SPREAD);

   int Total = OrdersTotal();
   
   if ( Total < 1 && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {
   // Controlla BUY Order
   if ( TradeStatus == 1 )
    {   
      
      // Controlla SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Ask-StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Ask+TakeProfit*Point;
      
      // Piazza l'ordine BUY
      Ticket=OrderSend(Symbol(),OP_BUY,Lots,Ask,Slippage,SL,TP,"BUY ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 2; // Prossimo trade  Sell 
            
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON BUY ORDER (",Errore,") : ",ErrorDescription(Errore));
      }  
     } 
   }
  
   Total = OrdersTotal();
   if ( Total < 1 && DayOfWeek()>=1 && DayOfWeek()<=5 ) 
   {  
     // Controlla SELL Order
     if ( TradeStatus == 2 )
     {
 
      // Setta SL 
      if (StopLoss < MarketInfo(Symbol(),MODE_STOPLEVEL)) StopLoss = MarketInfo(Symbol(),MODE_STOPLEVEL);
      if (StopLoss == 0) SL = 0;
      SL = Bid+StopLoss*Point;
      if (TakeProfit == 0) TP = 0;
      else TP = Bid-TakeProfit*Point;
      
      // Piazza Ordine SELL       
      Ticket=OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,SL,TP,"SELL ORDER",MagicNumber,0,Blue);
      
      TradeStatus = 1; // Prossimo trade  Buy
      
      if(Ticket<0)
      {
       Errore=GetLastError();
       Print("ERROR ON SELL ORDER (",Errore,") : ",ErrorDescription(Errore));
      } 
     }    
   }
}

// ===== Routine per controllare il trend ===== 
string CheckTrend(int DaysShift)
{
 if ( SundayCandleExists == true ) 
 {
  if ( DayOfWeek()==1 ) DaysShift = DaysShift+1; // Se esiste la candela di domenica non la prende in considerazione
 }
 if (iOpen(NULL,PERIOD_D1,DaysShift)<=iClose(NULL,PERIOD_D1,DaysShift)) return("BULLISH");
 else return("BEARISH");
}

// ===== Routine per il calcolo del Lot nel caso di Money Management =====
double CalcolaLot(int Rischio)
{
  double Lot=0;
  Lot=AccountEquity()* Rischio/100/1000;
  if( Lot>=0.1 )
  {
    Lot = NormalizeDouble(Lot,1); 
  }
  else Lot = NormalizeDouble(Lot,2);
  if (Lot > MarketInfo(Symbol(),MODE_MAXLOT)) { Lot = MarketInfo(Symbol(),MODE_MAXLOT); } // Avoid possible Lot value overflow if lot exceed maximum value allowed by broker
  if (Lot < MarketInfo(Symbol(),MODE_MINLOT)) { Lot = MarketInfo(Symbol(),MODE_MINLOT); } // Avoid possible Lot value overflow if lot exceed minimum value allowed by broker
  return(Lot);
}

// ===== Routine per calcolare MagicNumber diverso per ogni coppia e periodo =====
int MagicFromSymbol() 
{ // included by Renato 
   int MagicNumber=0;  
   for (int i=0; i<5; i++) 
   {  
     MagicNumber=MagicNumber*3+StringGetChar(Symbol(),i);  
   }  
   MagicNumber=MagicNumber*3+Period();  
   return(MagicNumber);  
}

//+------------------------------------------------------------------+